@@ -10,7 +10,7 @@ __author__ = "Evan Spotte-Smith <ewcspottesmith@lbl.gov>"
 
 @pytest.fixture(scope="session")
 def tasks_store(test_dir):
-    return JSONStore(test_dir / "C3H4Li1O3.json.gz")
+    return JSONStore(test_dir / "C2H4.json.gz")
 
 
 @pytest.fixture(scope="session")
@@ -36,9 +36,9 @@ def test_bonding_builder(tasks_store, mol_store, bonds_store):
         tasks_store,
         mol_store,
         bonds_store,
-        methods=["critic2", "OpenBabelNN + metal_edge_extender"],
+        methods=["critic2", "OpenBabelNN + metal_edge_extender", "nbo"],
     )
     builder.run()
 
-    assert bonds_store.count() == 90
+    assert bonds_store.count() == 64
     assert bonds_store.count({"deprecated": True}) == 0
